@@ -10,16 +10,16 @@ use IO::File;
 use Carp;
 use Scalar::Util ();
 
-use IO::Compress::Base::Common  2.081 qw(:Status);
-use IO::Compress::Zip::Constants 2.081 ;
-use IO::Uncompress::Unzip 2.081 ;
+use IO::Compress::Base::Common  2.088 qw(:Status);
+use IO::Compress::Zip::Constants 2.088 ;
+use IO::Uncompress::Unzip 2.088 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $SimpleUnzipError);
 
-$VERSION = '0.025';
+$VERSION = '0.026';
 $SimpleUnzipError = '';
 
 @ISA    = qw(IO::Uncompress::Unzip Exporter);
@@ -141,29 +141,15 @@ sub DESTROY
     my $self = shift;
 }
 
-sub _readLocalHeader
+sub resetter
 {
-    my $self = shift;
+    my $inner = shift;
     my $member = shift;
 
-    my $inner = $self->{Inner};
-    my $status = $inner->smartSeek($member->{LocalHeaderOffset}, 0, SEEK_SET);
-
-    #*$inner->{InputLength} = undef;
-    #*$inner->{InputLengthRemaining} = undef;
-    #*$inner->{BufferOffset}      = 0 ;
-    #*$inner->{Prime}      = '' ;
-
-    $inner->_readFullZipHeader() ;
 
     *$inner->{NewStream} = 0 ;
     *$inner->{EndStream} = 0 ;
-#    *$inner->{CompressedInputLengthDone} = undef ;
-#    *$inner->{CompressedInputLength} = undef ;
     *$inner->{TotalInflatedBytesRead} = 0;
-#    $inner->reset();
-#    *$inner->{UnCompSize}->reset();
-#    *$inner->{CompSize}->reset();
     *$inner->{Info}{TrailerLength} = 0;
 
     # disable streaming if present & set sizes from central dir
@@ -174,7 +160,21 @@ sub _readLocalHeader
     *$inner->{ZipData}{CompressedLen} = $member->{CompressedLength};
     *$inner->{ZipData}{UnCompressedLen} = $member->{UncompressedLength};
     *$inner->{CompressedInputLengthRemaining} =
-            *$inner->{CompressedInputLength} = $member->{CompressedLength};
+            *$inner->{CompressedInputLength} = $member->{CompressedLength};    
+}
+
+sub _readLocalHeader
+{
+    my $self = shift;
+    my $member = shift;
+
+    my $inner = $self->{Inner};
+
+    resetter($inner, $member);
+
+    my $status = $inner->smartSeek($member->{LocalHeaderOffset}, 0, SEEK_SET);
+    $inner->_readFullZipHeader() ;
+    $member->{DataOffset} = $inner->smartTell();
 }
 
 sub comment
@@ -275,12 +275,10 @@ sub content
     my $self = shift;
     my $name = shift;
 
-    return undef
-        if ! exists $self->{Members}{$name};
+    my $member = $self->member($name)
+        or return undef ;
 
-    $self->{Inner}->read(my $data, $self->{Info}{UncompressedLength});
-
-    return $data;
+    return $member->content();
 }
 
 sub exists
@@ -614,6 +612,8 @@ sub STORABLE_thaw
     package Archive::Zip::SimpleUnzip::Member;
 
     use IO::File ;
+    use File::Basename;
+    use File::Path ;
 
     sub name
     {
@@ -680,7 +680,12 @@ sub STORABLE_thaw
         my $self = shift;
         my $data ;
 
-        # $self->{Inner}->read($data, $self->{UncompressedLength});
+        my $inner = $self->{Inner};
+
+        $inner->reset() if $self->{NeedsReset}; $self->{NeedsReset} ++ ;
+        Archive::Zip::SimpleUnzip::resetter($inner, $self->{Info});
+
+        $inner->smartSeek($self->{Info}{DataOffset}, 0, SEEK_SET);
         $self->{Inner}->read($data, $self->{Info}{UncompressedLength});
 
         return $data;
@@ -700,6 +705,12 @@ sub STORABLE_thaw
 
         *$z->{Open} = 1 ;
         *$z->{SZ} = $self->{Inner};
+
+        my $inner = $self->{Inner};
+        $inner->reset() if $self->{NeedsReset}; $self->{NeedsReset} ++ ;
+        Archive::Zip::SimpleUnzip::resetter($self->{Inner}, $self->{Info});
+        $inner->smartSeek($self->{Info}{DataOffset}, 0, SEEK_SET);
+
         Scalar::Util::weaken *$z->{SZ}; # for 5.8
 
         $z;
@@ -759,21 +770,37 @@ sub STORABLE_thaw
         my $self = shift;
         my $out  = shift;
 
-        my @path = _canonicalPath(defined $out ? $out : $self->{Info}{Name}) ;
-        my $filename = join '/', @path ;
-        pop @path
-            if ! $self->isDirectory();
-        
-        my @dir  ;
+        my $path ;
+        my $filename ;
 
-        while (@path)
+        if (defined $out)
         {
-            push @dir, shift @path;
-            my $dir = join '/', @dir;
-            mkdir $dir
-                or return _setError("Cannot create path '$dir': $!");
+            # User has supplied output file, so allow absolute path
+            $filename = $out;
+        }
+        else
+        {
+            # using name in zip file, so make it safe
+            my @path = _canonicalPath(defined $out ? $out : $self->{Info}{Name}) ;
+            $filename = join '/', @path ;
         }
 
+        $path = $self->isDirectory() ? $filename : dirname $filename;
+
+        if (defined $path)
+        {
+            # check path isn't already a plain file
+            return _setError("Path is not a directory '$path'")
+                if -e $path && ! -d $path ;
+
+            if (! -d $path)
+            {
+                my $error ;
+                File::Path::mkpath($path, {error => \$error}) 
+                    or return _setError("Cannot create path '$path': $error");
+            }
+        }
+               
         # TODO - symlink
 
         if ($self->isFile())
@@ -1005,8 +1032,6 @@ Archive::Zip::SimpleUnzip is a module that allows reading of Zip archives.
 For writing Zip archives, there is a companion module,
 called L<Archive::Zip::SimpleZip>, that can create Zip archives.
 
-B<NOTE> This is late alpha quality code, so the interface may change.
-
 =head2 Features
 
 =over 5
@@ -1330,6 +1355,13 @@ The following features are not currently supported.
 
 =back
 
+=head1 SUPPORT
+
+General feedback/questions/bug reports should be sent to 
+L<https://github.com/pmqs/Archive-Zip-SimpleZip/issues> (preferred) or
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Archive-Zip-SimpleZip>.
+
+
 =head1 SEE ALSO
 
 
